Checks output of an English sentence tokenizer and modifies the output according to default or user-defined rules.

For the full documentation, please see the repository:

https://github.com/Rairye/sentence-tk-checker